from dataclasses import dataclass, field
from typing import List, Optional

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:admi.009.001.02"


@dataclass
class RequestDetails3:
    tp: Optional[str] = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.009.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    key: Optional[str] = field(
        default=None,
        metadata={
            "name": "Key",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.009.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class SupplementaryDataEnvelope1:
    any_element: Optional[object] = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        },
    )


@dataclass
class SupplementaryData1:
    plc_and_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "PlcAndNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.009.001.02",
            "min_length": 1,
            "max_length": 350,
        },
    )
    envlp: Optional[SupplementaryDataEnvelope1] = field(
        default=None,
        metadata={
            "name": "Envlp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.009.001.02",
            "required": True,
        },
    )


@dataclass
class StaticDataRequestV02:
    msg_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "MsgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.009.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    sttlm_ssn_idr: Optional[str] = field(
        default=None,
        metadata={
            "name": "SttlmSsnIdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.009.001.02",
            "pattern": r"[a-zA-Z0-9]{4}",
        },
    )
    data_req_dtls: Optional[RequestDetails3] = field(
        default=None,
        metadata={
            "name": "DataReqDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.009.001.02",
            "required": True,
        },
    )
    splmtry_data: List[SupplementaryData1] = field(
        default_factory=list,
        metadata={
            "name": "SplmtryData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.009.001.02",
        },
    )


@dataclass
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:admi.009.001.02"

    statc_data_req: Optional[StaticDataRequestV02] = field(
        default=None,
        metadata={
            "name": "StatcDataReq",
            "type": "Element",
            "required": True,
        },
    )



from pyiso20022.pain.pain_014_001_09.pain_014_001_09 import (
    AccountIdentification4Choice,
    AccountSchemeName1Choice,
    ActiveCurrencyAndAmount,
    ActiveOrHistoricCurrencyAndAmount,
    AddressType2Code,
    AddressType3Choice,
    AmountOrRate1Choice,
    AmountType4Choice,
    BranchAndFinancialInstitutionIdentification6,
    BranchData3,
    CashAccount40,
    CashAccountType2Choice,
    CategoryPurpose1Choice,
    Charges7,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    Contact4,
    CreditDebitCode,
    CreditorPaymentActivationRequestStatusReportV09,
    CreditorReferenceInformation2,
    CreditorReferenceType1Choice,
    CreditorReferenceType2,
    CreditTransferMandateData1,
    DateAndDateTime2Choice,
    DateAndPlaceOfBirth1,
    DatePeriod2,
    DiscountAmountAndType1,
    DiscountAmountType1Choice,
    Document,
    Document12,
    DocumentAdjustment1,
    DocumentFormat1Choice,
    DocumentLineIdentification1,
    DocumentLineInformation1,
    DocumentLineType1,
    DocumentLineType1Choice,
    DocumentType1Choice,
    DocumentType3Code,
    DocumentType6Code,
    EquivalentAmount2,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification18,
    Frequency6Code,
    Frequency36Choice,
    FrequencyAndMoment1,
    FrequencyPeriod1,
    Garnishment3,
    GarnishmentType1,
    GarnishmentType1Choice,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GenericIdentification1,
    GenericIdentification30,
    GenericOrganisationIdentification1,
    GenericPersonIdentification1,
    GroupHeader87,
    LocalInstrument2Choice,
    MandateClassification1Choice,
    MandateClassification1Code,
    MandateSetupReason1Choice,
    MandateTypeInformation2,
    NamePrefix2Code,
    NumberOfTransactionsPerStatus5,
    OrganisationIdentification29,
    OrganisationIdentificationSchemeName1Choice,
    OriginalGroupInformation30,
    OriginalPaymentInstruction42,
    OriginalTransactionReference37,
    OtherContact1,
    Party38Choice,
    PartyAndSignature3,
    PartyIdentification135,
    PaymentCondition1,
    PaymentConditionStatus1,
    PaymentMethod4Code,
    PaymentTransaction136,
    PaymentTypeInformation26,
    PersonIdentification13,
    PersonIdentificationSchemeName1Choice,
    PostalAddress24,
    PreferredContactMethod1Code,
    Priority2Code,
    ProxyAccountIdentification1,
    ProxyAccountType1Choice,
    ReferredDocumentInformation7,
    ReferredDocumentType3Choice,
    ReferredDocumentType4,
    RemittanceAmount2,
    RemittanceAmount3,
    RemittanceInformation21,
    ServiceLevel8Choice,
    SkipPayload,
    StatusReason6Choice,
    StatusReasonInformation12,
    StructuredRemittanceInformation17,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    TaxAmount3,
    TaxAmountAndType1,
    TaxAmountType1Choice,
    TaxAuthorisation1,
    TaxData1,
    TaxParty1,
    TaxParty2,
    TaxPeriod3,
    TaxRecord3,
    TaxRecordDetails3,
    TaxRecordPeriod1Code,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountSchemeName1Choice",
    "ActiveCurrencyAndAmount",
    "ActiveOrHistoricCurrencyAndAmount",
    "AddressType2Code",
    "AddressType3Choice",
    "AmountOrRate1Choice",
    "AmountType4Choice",
    "BranchAndFinancialInstitutionIdentification6",
    "BranchData3",
    "CashAccount40",
    "CashAccountType2Choice",
    "CategoryPurpose1Choice",
    "Charges7",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "Contact4",
    "CreditDebitCode",
    "CreditTransferMandateData1",
    "CreditorPaymentActivationRequestStatusReportV09",
    "CreditorReferenceInformation2",
    "CreditorReferenceType1Choice",
    "CreditorReferenceType2",
    "DateAndDateTime2Choice",
    "DateAndPlaceOfBirth1",
    "DatePeriod2",
    "DiscountAmountAndType1",
    "DiscountAmountType1Choice",
    "Document",
    "Document12",
    "DocumentAdjustment1",
    "DocumentFormat1Choice",
    "DocumentLineIdentification1",
    "DocumentLineInformation1",
    "DocumentLineType1",
    "DocumentLineType1Choice",
    "DocumentType1Choice",
    "DocumentType3Code",
    "DocumentType6Code",
    "EquivalentAmount2",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification18",
    "Frequency36Choice",
    "Frequency6Code",
    "FrequencyAndMoment1",
    "FrequencyPeriod1",
    "Garnishment3",
    "GarnishmentType1",
    "GarnishmentType1Choice",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GenericIdentification1",
    "GenericIdentification30",
    "GenericOrganisationIdentification1",
    "GenericPersonIdentification1",
    "GroupHeader87",
    "LocalInstrument2Choice",
    "MandateClassification1Choice",
    "MandateClassification1Code",
    "MandateSetupReason1Choice",
    "MandateTypeInformation2",
    "NamePrefix2Code",
    "NumberOfTransactionsPerStatus5",
    "OrganisationIdentification29",
    "OrganisationIdentificationSchemeName1Choice",
    "OriginalGroupInformation30",
    "OriginalPaymentInstruction42",
    "OriginalTransactionReference37",
    "OtherContact1",
    "Party38Choice",
    "PartyAndSignature3",
    "PartyIdentification135",
    "PaymentCondition1",
    "PaymentConditionStatus1",
    "PaymentMethod4Code",
    "PaymentTransaction136",
    "PaymentTypeInformation26",
    "PersonIdentification13",
    "PersonIdentificationSchemeName1Choice",
    "PostalAddress24",
    "PreferredContactMethod1Code",
    "Priority2Code",
    "ProxyAccountIdentification1",
    "ProxyAccountType1Choice",
    "ReferredDocumentInformation7",
    "ReferredDocumentType3Choice",
    "ReferredDocumentType4",
    "RemittanceAmount2",
    "RemittanceAmount3",
    "RemittanceInformation21",
    "ServiceLevel8Choice",
    "SkipPayload",
    "StatusReason6Choice",
    "StatusReasonInformation12",
    "StructuredRemittanceInformation17",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "TaxAmount3",
    "TaxAmountAndType1",
    "TaxAmountType1Choice",
    "TaxAuthorisation1",
    "TaxData1",
    "TaxParty1",
    "TaxParty2",
    "TaxPeriod3",
    "TaxRecord3",
    "TaxRecordDetails3",
    "TaxRecordPeriod1Code",
]



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pyiso20022",
    version="1.3.3",
    author="Peter Houghton",
    author_email="pete@investigatingsoftware.co.uk",
    description="pyiso20022 is a library for generating ISO20022 messages in Python.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/phoughton/pyiso20022",
    packages=setuptools.find_packages(),
    install_requires=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
)



from dataclasses import dataclass, field
from typing import List, Optional

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02"


@dataclass
class ReportParameter1:
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 70,
        },
    )
    val: Optional[str] = field(
        default=None,
        metadata={
            "name": "Val",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 350,
        },
    )


@dataclass
class SupplementaryDataEnvelope1:
    any_element: Optional[object] = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        },
    )


@dataclass
class RequestDetails4:
    key: Optional[str] = field(
        default=None,
        metadata={
            "name": "Key",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    rpt_data: List[ReportParameter1] = field(
        default_factory=list,
        metadata={
            "name": "RptData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
        },
    )


@dataclass
class SupplementaryData1:
    plc_and_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "PlcAndNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
            "min_length": 1,
            "max_length": 350,
        },
    )
    envlp: Optional[SupplementaryDataEnvelope1] = field(
        default=None,
        metadata={
            "name": "Envlp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
            "required": True,
        },
    )


@dataclass
class RequestDetails5:
    tp: Optional[str] = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    req_ref: Optional[str] = field(
        default=None,
        metadata={
            "name": "ReqRef",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    rpt_key: List[RequestDetails4] = field(
        default_factory=list,
        metadata={
            "name": "RptKey",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
            "min_occurs": 1,
        },
    )


@dataclass
class StaticDataReportV02:
    msg_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "MsgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    sttlm_ssn_idr: Optional[str] = field(
        default=None,
        metadata={
            "name": "SttlmSsnIdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
            "pattern": r"[a-zA-Z0-9]{4}",
        },
    )
    rpt_dtls: Optional[RequestDetails5] = field(
        default=None,
        metadata={
            "name": "RptDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
            "required": True,
        },
    )
    splmtry_data: List[SupplementaryData1] = field(
        default_factory=list,
        metadata={
            "name": "SplmtryData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02",
        },
    )


@dataclass
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:admi.010.001.02"

    statc_data_rpt: Optional[StaticDataReportV02] = field(
        default=None,
        metadata={
            "name": "StatcDataRpt",
            "type": "Element",
            "required": True,
        },
    )
